@@ -45,13 +45,13 @@ except ImportError:
 
 @magic_arguments.magic_arguments()
 @magic_arguments.argument(
-    "destination_var",
-    nargs="?",
+    "--dest",
+    type=str,
     help=("If provided, save the output to this variable instead of displaying it."),
 )
 @magic_arguments.argument(
-    "stats_var",
-    nargs="?",
+    "--stats",
+    type=str,
     help=("If provided, save the output to this variable instead of displaying it."),
 )
 @magic_arguments.argument(
@@ -102,6 +102,24 @@ except ImportError:
             "Object containing paramters as key/value pairs"
     ),
 )
+@magic_arguments.argument(
+    "--hostname",
+    type=str,
+    default=None,
+    help=(
+            "Provide the hostname"
+    ),
+)
+
+@magic_arguments.argument(
+    "--log_query_results",
+    type=bool,
+    default=True,
+    help=(
+            "If to print query stats results"
+    ),
+)
+
 
 def _cell_magic(line, query):
     """Underlying function for superquery cell magic
@@ -123,6 +141,8 @@ def _cell_magic(line, query):
         client = Client(usernameDriveAuth=args.username)
     else:
         client = Client()
+
+    client.set_log_query_results(args.log_query_results)
     
     # Strip input query
     QUERY = query.strip()
@@ -153,7 +173,10 @@ def _cell_magic(line, query):
     # Get query result
     try:
         print("[sQ] Executing query...")
-        result = client.query(QUERY, dry_run=args.dry_run)
+        if args.hostname:
+            result = client.query(QUERY, dry_run=args.dry_run, hostname=args.hostname)
+        else:
+            result = client.query(QUERY, dry_run=args.dry_run)
     except Exception as ex:
         LOGGER.error("An error occurred")
         LOGGER.exception(ex)
@@ -161,13 +184,13 @@ def _cell_magic(line, query):
 
     if args.dry_run:
         return
-    elif args.destination_var:
-        IPython.get_ipython().push({args.destination_var: result.to_df()})
+    elif args.dest:
+        IPython.get_ipython().push({args.dest: result.to_df()})
         # Stats
-        if args.stats_var:
+        if args.stats:
             df_stats = pd.DataFrame.from_dict(result.stats.to_dict(), orient='index').reset_index()
             df_stats.columns = ["statistic", "value"]
-            IPython.get_ipython().push({args.stats_var: df_stats})
+            IPython.get_ipython().push({args.stats: df_stats})
         return
     else:
         return result.to_df()
